==> eiffelstudio-18.01.10.1424.tar: F_code/C5/gr230.c <==
/*
 * Code for class GRAPHICAL_WIZARD_INTEGER_QUESTION
 */

#include "eif_eiffel.h"
#include "../E1/estructure.h"
#include "../E1/eoffsets.h"

#include "gr230.h"
#include "eif_out.h"

#ifdef __cplusplus
extern "C" {
#endif


#ifdef __cplusplus
}
#endif


#ifdef __cplusplus
extern "C" {
#endif

/* {GRAPHICAL_WIZARD_INTEGER_QUESTION}.initialize */
void F474_4511 (EIF_REFERENCE Current)
{
	GTCX
	EIF_REFERENCE loc1 = (EIF_REFERENCE) 0;
	EIF_REFERENCE loc2 = (EIF_REFERENCE) 0;
	EIF_REFERENCE loc3 = (EIF_REFERENCE) 0;
	EIF_REFERENCE loc4 = (EIF_REFERENCE) 0;
	EIF_REFERENCE tr1 = NULL;
	EIF_REFERENCE tr2 = NULL;
	EIF_REFERENCE tr3 = NULL;
	EIF_REFERENCE tr4 = NULL;
	RTCFDT;
	RTLD;
	
	RTLI(9);
	RTLR(0,loc1);
	RTLR(1,tr1);
	RTLR(2,loc2);
	RTLR(3,Current);
	RTLR(4,loc3);
	RTLR(5,loc4);
	RTLR(6,tr2);
	RTLR(7,tr3);
	RTLR(8,tr4);
	RTLIU(9);
	
	RTGC;
	tr1 = RTLNS(eif_new_type(1076, 0x01).id, 1076, _OBJSIZ_6_3_0_1_0_0_0_0_);
	F1032_8649(RTCW(tr1));
	loc1 = (EIF_REFERENCE) tr1;
	F1075_9321(RTCW(loc1), ((EIF_INTEGER_32) 5L));
	tr1 = RTLNS(eif_new_type(1094, 0x01).id, 1094, _OBJSIZ_5_2_0_1_0_0_0_0_);
	F1060_9031(RTCW(tr1), *(EIF_REFERENCE *)(Current + _REFACS_2_));
	loc2 = (EIF_REFERENCE) tr1;
	RTAR(Current, loc2);
	*(EIF_REFERENCE *)(Current + _REFACS_5_) = (EIF_REFERENCE) loc2;
	F89_2450(Current, loc2);
	F1068_9180(RTCW(loc1), loc2);
	F1075_9324(RTCW(loc1), loc2);
	tr1 = RTLNSMART(eif_new_type(1098, 1).id);
	F1032_8649(RTCW(tr1));
	loc3 = (EIF_REFERENCE) tr1;
	RTAR(Current, loc3);
	*(EIF_REFERENCE *)(Current + _REFACS_4_) = (EIF_REFERENCE) loc3;
	F1068_9180(RTCW(loc1), loc3);
	F1075_9324(RTCW(loc1), loc3);
	tr1 = *(EIF_REFERENCE *)(Current + _REFACS_3_);
	loc4 = tr1;
	if (EIF_TEST(loc4)) {
		tr1 = RTLNS(eif_new_type(1094, 0x01).id, 1094, _OBJSIZ_5_2_0_1_0_0_0_0_);
		F1060_9031(RTCW(tr1), loc4);
		loc2 = (EIF_REFERENCE) tr1;
		F89_2454(Current, loc2);
		F473_4510(Current, loc2, loc1);
	}
	{
		static EIF_TYPE_INDEX typarr0[] = {0xFFF9,1,916,0xFF01,0,0xFFFF};
		EIF_TYPE typres0;
		typarr0[4] = dftype;
		
		typres0 = eif_compound_id(dftype, typarr0);
		tr1 = RTLNTS(typres0.id, 2, 0);
	}
	((EIF_TYPED_VALUE *)tr1+1)->it_r = Current;
	RTAR(tr1,Current);
	
	{
		static EIF_TYPE_INDEX typarr0[] = {0xFF01,990,0xFF01,0xFFF9,1,916,0xFF01,799,0xFFFF};
		EIF_TYPE typres0;
		static EIF_TYPE typcache0 = {INVALID_DTYPE, 0};
		
		typres0 = (typcache0.id != INVALID_DTYPE ? typcache0 : (typcache0 = eif_compound_id(dftype, typarr0)));
		tr4 = RTLNRF(typres0.id, (EIF_POINTER) __A230_88_2, (EIF_POINTER) _A230_88_2, (EIF_POINTER)(0),tr1, 1, 1);
	}
	F466_4492(Current, tr4);
	RTAR(Current, loc1);
	*(EIF_REFERENCE *)(Current + _REFACS_6_) = (EIF_REFERENCE) loc1;
	RTLE;
}

/* {GRAPHICAL_WIZARD_INTEGER_QUESTION}.widget */
EIF_REFERENCE F474_4512 (EIF_REFERENCE Current)
{
	return *(EIF_REFERENCE *)(Current + _REFACS_6_);
}


/* {GRAPHICAL_WIZARD_INTEGER_QUESTION}.input_widget */
EIF_REFERENCE F474_4513 (EIF_REFERENCE Current)
{
	return *(EIF_REFERENCE *)(Current + _REFACS_4_);
}


/* {GRAPHICAL_WIZARD_INTEGER_QUESTION}.title_widget */
EIF_REFERENCE F474_4514 (EIF_REFERENCE Current)
{
	return *(EIF_REFERENCE *)(Current + _REFACS_5_);
}


/* {GRAPHICAL_WIZARD_INTEGER_QUESTION}.text */
EIF_REFERENCE F474_4515 (EIF_REFERENCE Current)
{
	GTCX
	EIF_REFERENCE tr1 = NULL;
	EIF_REFERENCE Result = ((EIF_REFERENCE) 0);
	
	RTLD;
	
	RTLI(3);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLR(2,Result);
	RTLIU(3);
	
	RTGC;
	tr1 = *(EIF_REFERENCE *)(Current + _REFACS_4_);
	Result = F1060_9032(RTCW(tr1));
	RTLE;
	return Result;
}

/* {GRAPHICAL_WIZARD_INTEGER_QUESTION}.set_text */
void F474_4517 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	EIF_INTEGER_32 ti4_1;
	EIF_BOOLEAN tb1;
	RTLD;
	
	RTLI(2);
	RTLR(0,arg1);
	RTLR(1,Current);
	RTLIU(2);
	
	RTGC;
	if ((EIF_BOOLEAN)(arg1 == NULL)) {
		F474_4518(Current, ((EIF_INTEGER_32) 0L));
	} else {
		tb1 = F995_8110(RTCW(arg1));
		if (tb1) {
			ti4_1 = F995_8144(RTCW(arg1));
			F474_4518(Current, ti4_1);
		}
	}
	RTLE;
}

/* {GRAPHICAL_WIZARD_INTEGER_QUESTION}.set_value */
void F474_4518 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1)
{
	GTCX
	EIF_REFERENCE tr1 = NULL;
	EIF_REFERENCE tr2 = NULL;
	RTLD;
	
	RTLI(3);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLR(2,tr2);
	RTLIU(3);
	
	RTGC;
	tr1 = *(EIF_REFERENCE *)(Current + _REFACS_4_);
	tr2 = c_outi(arg1);
	F1060_9033(RTCW(tr1), tr2);
	RTLE;
}

/* {GRAPHICAL_WIZARD_INTEGER_QUESTION}.inline-agent#1 of initialize */
void F474_13357 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	EIF_REFERENCE tr1 = NULL;
	EIF_REFERENCE tr2 = NULL;
	EIF_BOOLEAN tb1;
	RTLD;
	
	RTLI(4);
	RTLR(0,Current);
	RTLR(1,arg1);
	RTLR(2,tr1);
	RTLR(3,tr2);
	RTLIU(4);
	
	RTGC;
	tb1 = F995_8110(RTCV(F474_4515(Current)));
	if ((EIF_BOOLEAN) !tb1) {
		tr1 = RTMS_EX_H("Invalid value for field [",25,113845595);
		tr1 = F1003_8486(tr1, *(EIF_REFERENCE *)(Current));
		tr2 = RTMS_EX_H("]: must be an integer!",22,786853665);
		tr1 = F1003_8486(RTCW(tr1), tr2);
		F800_5943(RTCW(arg1), tr1);
	}
	RTLE;
}

void EIF_Minit230 (void)
{
	GTCX
}


#ifdef __cplusplus
}
#endif

==> eiffelstudio-18.07.10.1981.tar: F_code/C5/gr230.c <==
/*
 * Code for class GRAPHICAL_WIZARD_DIRECTORY_QUESTION
 */

#include "eif_eiffel.h"
#include "../E1/estructure.h"
#include "../E1/eoffsets.h"

#include "gr230.h"

#ifdef __cplusplus
extern "C" {
#endif


#ifdef __cplusplus
}
#endif


#ifdef __cplusplus
extern "C" {
#endif

/* {GRAPHICAL_WIZARD_DIRECTORY_QUESTION}.initialize */
void F474_4511 (EIF_REFERENCE Current)
{
	GTCX
	EIF_REFERENCE loc1 = (EIF_REFERENCE) 0;
	EIF_REFERENCE loc2 = (EIF_REFERENCE) 0;
	EIF_REFERENCE loc3 = (EIF_REFERENCE) 0;
	EIF_REFERENCE loc4 = (EIF_REFERENCE) 0;
	EIF_REFERENCE tr1 = NULL;
	RTLD;
	
	RTLI(6);
	RTLR(0,loc1);
	RTLR(1,tr1);
	RTLR(2,loc2);
	RTLR(3,Current);
	RTLR(4,loc3);
	RTLR(5,loc4);
	RTLIU(6);
	
	RTGC;
	tr1 = RTLNS(eif_new_type(1076, 0x01).id, 1076, _OBJSIZ_6_3_0_1_0_0_0_0_);
	F1032_8651(RTCW(tr1));
	loc1 = (EIF_REFERENCE) tr1;
	F1075_9323(RTCW(loc1), ((EIF_INTEGER_32) 5L));
	tr1 = RTLNS(eif_new_type(1094, 0x01).id, 1094, _OBJSIZ_5_2_0_1_0_0_0_0_);
	F1060_9033(RTCW(tr1), *(EIF_REFERENCE *)(Current + _REFACS_2_));
	loc2 = (EIF_REFERENCE) tr1;
	RTAR(Current, loc2);
	*(EIF_REFERENCE *)(Current + _REFACS_5_) = (EIF_REFERENCE) loc2;
	F89_2450(Current, loc2);
	F1068_9182(RTCW(loc1), loc2);
	F1075_9326(RTCW(loc1), loc2);
	tr1 = RTLNSMART(eif_new_type(1077, 1).id);
	F1078_9333(RTCW(tr1));
	loc3 = (EIF_REFERENCE) tr1;
	F1078_9351(RTCW(loc3));
	RTAR(Current, loc3);
	*(EIF_REFERENCE *)(Current + _REFACS_4_) = (EIF_REFERENCE) loc3;
	F1068_9182(RTCW(loc1), loc3);
	F1075_9326(RTCW(loc1), loc3);
	tr1 = *(EIF_REFERENCE *)(Current + _REFACS_3_);
	loc4 = tr1;
	if (EIF_TEST(loc4)) {
		tr1 = RTLNS(eif_new_type(1094, 0x01).id, 1094, _OBJSIZ_5_2_0_1_0_0_0_0_);
		F1060_9033(RTCW(tr1), loc4);
		loc2 = (EIF_REFERENCE) tr1;
		F89_2454(Current, loc2);
		F473_4510(Current, loc2, loc1);
	}
	RTAR(Current, loc1);
	*(EIF_REFERENCE *)(Current + _REFACS_6_) = (EIF_REFERENCE) loc1;
	RTLE;
}

/* {GRAPHICAL_WIZARD_DIRECTORY_QUESTION}.widget */
EIF_REFERENCE F474_4512 (EIF_REFERENCE Current)
{
	return *(EIF_REFERENCE *)(Current + _REFACS_6_);
}


/* {GRAPHICAL_WIZARD_DIRECTORY_QUESTION}.input_widget */
EIF_REFERENCE F474_4513 (EIF_REFERENCE Current)
{
	return *(EIF_REFERENCE *)(Current + _REFACS_4_);
}


/* {GRAPHICAL_WIZARD_DIRECTORY_QUESTION}.title_widget */
EIF_REFERENCE F474_4514 (EIF_REFERENCE Current)
{
	return *(EIF_REFERENCE *)(Current + _REFACS_5_);
}


/* {GRAPHICAL_WIZARD_DIRECTORY_QUESTION}.text */
EIF_REFERENCE F474_4515 (EIF_REFERENCE Current)
{
	GTCX
	EIF_REFERENCE tr1 = NULL;
	EIF_REFERENCE Result = ((EIF_REFERENCE) 0);
	
	RTLD;
	
	RTLI(3);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLR(2,Result);
	RTLIU(3);
	
	RTGC;
	tr1 = *(EIF_REFERENCE *)(Current + _REFACS_4_);
	Result = F1078_9341(RTCW(tr1));
	RTLE;
	return Result;
}

/* {GRAPHICAL_WIZARD_DIRECTORY_QUESTION}.set_text */
void F474_4517 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	EIF_REFERENCE tr1 = NULL;
	RTLD;
	
	RTLI(3);
	RTLR(0,arg1);
	RTLR(1,Current);
	RTLR(2,tr1);
	RTLIU(3);
	
	RTGC;
	if ((EIF_BOOLEAN)(arg1 == NULL)) {
		F474_4519(Current, NULL);
	} else {
		tr1 = RTLNS(eif_new_type(868, 0x01).id, 868, _OBJSIZ_2_1_0_0_0_0_0_0_);
		F869_6812(RTCW(tr1), arg1);
		F474_4519(Current, tr1);
	}
	RTLE;
}

/* {GRAPHICAL_WIZARD_DIRECTORY_QUESTION}.set_value */
void F474_4519 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	EIF_REFERENCE tr1 = NULL;
	EIF_REFERENCE tr2 = NULL;
	RTLD;
	
	RTLI(4);
	RTLR(0,arg1);
	RTLR(1,Current);
	RTLR(2,tr1);
	RTLR(3,tr2);
	RTLIU(4);
	
	RTGC;
	if ((EIF_BOOLEAN)(arg1 == NULL)) {
		tr1 = *(EIF_REFERENCE *)(Current + _REFACS_4_);
		tr2 = RTMS_EX_H("",0,0);
		F1078_9345(RTCW(tr1), tr2);
	} else {
		tr1 = *(EIF_REFERENCE *)(Current + _REFACS_4_);
		tr2 = F869_6851(RTCW(arg1));
		F1078_9345(RTCW(tr1), tr2);
	}
	RTLE;
}

void EIF_Minit230 (void)
{
	GTCX
}


#ifdef __cplusplus
}
#endif
